[![PyPI badge](http://img.shields.io/pypi/v/sciline.svg)](https://pypi.python.org/pypi/sciline)
[![Anaconda-Server Badge](https://anaconda.org/scipp/sciline/badges/version.svg)](https://anaconda.org/scipp/sciline)
[![License: BSD 3-Clause](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](LICENSE)

# sciline

## About

Build scientific pipelines for your data

## Installation

```sh
python -m pip install sciline
```
